#!/usr/bin/ksh

##-------------------------------------------------------------------#
## %PS
##
## Licensed Internal Code - Property of IBM
##
## 2105 Licensed Internal Code
##
## (C) Copyright IBM Corp. 1999 All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
## %EPS
##
## COMPONENT_NAME (RAS WUI)
##
## Function: rsList2105DPO.sh
##
##-------------------------------------------------------------------#
##
## Filename: rsList2105DPO.sh
##
## Subsystem: RAS WUI
##
## Input:       rsList2105DPO.sh -f inputfile -i inputfile2 -n
##
## Description: collects host device file names for 2105 disks 
##              configured on system.
##
## Change History:
##   Modifier               Date                         Change ID
##-------------------------------------------------------------------#
##  John Wrobel & 
##  Ramandeep Kaur        08/01/2000                      ?????? 
##      Initial version
##  Ramandeep Kaur        08/17/2000                      39254
##      Deleted the blank line from the output 
##  Ruth E. Azevedo       08/28/2000                      39885 
##      AIX parse of datapath query no dependable on field length
##  Susanne Lukas &       11-14-2000                      43080
##  Ramandeep Kaur
##      Included check to find string DEV or Dev in Sun output file 
##-------------------------------------------------------------------#
## End of PROLOG

rm -rf /tmp/*.list2105DPO.temp

#--------------------------------------------------------------------#
# Initialization
#--------------------------------------------------------------------#
Firsttime=0
OS=`uname | cut -c 1-3`
NOHEADER=

#--------------------------------------------------------------------#
# Get options
#--------------------------------------------------------------------#
while getopts "f:i:n" opt; do
   case $opt in
      f ) FILE=$OPTARG;;
      i ) FILE_TWO=$OPTARG;;
      n ) NOHEADER=1
   esac
done

#--------------------------------------------------------------------#
# Function printoutput 
#--------------------------------------------------------------------#
function printoutput {
        if [[ -z $NOHEADER ]]; then
           if [[ $Firsttime -eq 0 ]]; then
              printf " VpathName     Serial     VolumeNames\n"
              printf "-----------    ------     -----------\n"
              Firsttime=1
           fi
           if [[ ${#NAME} > 8 ]]; then
             printf " %s    " $NAME
           elif [[ ${#NAME} > 7 ]]; then
             printf " %s     " $NAME
           elif [[ ${#NAME} > 6 ]]; then
             printf " %s      " $NAME 
           elif [[ ${#NAME} > 5 ]]; then
              printf " %s       " $NAME
           fi
           if [[ $count -ge 0 ]]; then
              print $SERIAL "  "  ${DSK[0]} ${DSK[1]} ${DSK[2]} ${DSK[3]} ${DSK[4]} ${DSK[5]} ${DSK[6]} ${DSK[7]}
           fi
           if [[ $count -gt 8 ]]; then
              print "                         " ${DSK[8]} ${DSK[9]} ${DSK[10]} ${DSK[11]} ${DSK[12]} ${DSK[13]} ${DSK[14]} ${DSK[15]}
           fi
           if [[ $count -gt 16 ]]; then
              print "                         " ${DSK[16]} ${DSK[17]} ${DSK[18]} ${DSK[19]} ${DSK[20]} ${DSK[21]} ${DSK[22]} ${DSK[23]}
           fi
           if [[ $count -gt 24 ]]; then
              print "                         " ${DSK[24]} ${DSK[25]} ${DSK[26]} ${DSK[27]} ${DSK[28]} ${DSK[29]} ${DSK[30]} ${DSK[31]}
           fi
        else
          echo $NAME
          echo $SERIAL
        fi
        count=0
        set -A DSK
}


##-------------------------------------------------------------------#
## AIX and HP specific code
##-------------------------------------------------------------------#
if [[ $OS = "AIX" ||  $OS = "HP-" ]]; then
Index=`cat $FILE | wc -l`
exec 3< $FILE         
read -u3 line
Field=`print $line | awk '{ print $1;}'`

Counter=0
count=0

while [[ $Counter -ge 0 && $Counter -le $Index ]]; do
if [[ $Field = "" && $Counter -ne $Index ]]; then
    read -u3 line
    let Counter=$Counter+1
    Field=`print $line | awk '{ print $1;}'`
fi
if [[ $Field = "Total" ]]; then
    read -u3 line
    let Counter=$Counter+1
    Field=`print $line | awk '{ print $1;}'`
fi

if [[ $Field = "Dev#:" || $Field = "DEV#:" || $Counter -eq $Index ]]; then
   if [[ $Counter -eq $Index ]]; then
      let Counter=$Counter+1
   fi   
   if [[ $count -ge 0 ]]; then
       printoutput
   fi
   TYPE=`print $line | awk '{ print substr($7,1,4)}'`
     if [[ $TYPE = "2105" ]]; then
       NAME=`print $line | awk '{ print $5;}'`
       SERIAL=`print $line | awk '{ print $9;}'`
       read -u3 line
       let Counter=$Counter+1
       read -u3 line
       let Counter=$Counter+1
       read -u3 line
       let Counter=$Counter+1
       Field=`print $line | awk '{ print $1;}'`
     fi

 elif [[ $Field -ge 0 && $Field -le 31 ]]; then
       if [[ $OS = "AIX" ]]; then
##       CMVC 39885, next three lines 
         TEMPDSK=`print $line | awk '{ print $2}'`
         TDSK=`print $TEMPDSK | sed "s/\// /" | awk '/scsi/ {print $2}'`
         DSK[$count]=$TDSK
       else
         DSK[$count]=`print $line | awk '{ print $3}'`
       fi
       count=$(($count + 1))
       read -u3 line
       let Counter=$Counter+1
       Field=`print $line | awk '{ print $1;}'`
else
       read -u3 line
       let Counter=$Counter+1
       Field=`print $line | awk '{ print $1;}'`
fi
done    
fi

##-------------------------------------------------------------------#
## Sun specific code
##-------------------------------------------------------------------#
if [[ $OS = "Sun" ]]; then


Date=`date`
TEMPFILE=`print $Date | awk '{ print "/tmp/"$2"."$3"."$4".list2105DPO.temp"}'`


X="cat $FILE | awk '\$1 ~ /DEV#:/' > $TEMPFILE"
`eval $X`
if [[ ! -s $TEMPFILE ]]; then
  X="cat $FILE | awk '\$1 ~ /Dev#:/' > $TEMPFILE"
  `eval $X`
fi 

Index=`cat $TEMPFILE | wc -l`


exec 3< $TEMPFILE

read -u3 line
Field=`print $line | awk '{ print $1;}'`

Counter=0

while [[ $Counter -ge 0 && $Counter -le $Index ]]; do
if [[ $Field = "DEV#:" || $Field = "Dev#:" || $Counter -eq $Index ]]; then
  Type=`print $line | awk '{ print substr($7,1,4)}'`
  if [[ $Type = "2105" ]]; then
      pathWidth=`print $line | awk '{ print length($5)}'`
      lastchar=`print $line | awk '{ print substr($5,length($5))}'`
      if [[ $lastchar = "0" || $lastchar = "1" || $lastchar = "2" || $lastchar = "3" ||
            $lastchar = "4" || $lastchar = "5" || $lastchar = "6" || $lastchar = "7" ||
            $lastchar = "8" || $lastchar = "9" ]]; then
         NAME=`print $line | awk '{ print $5}'`
      else
         NAME=`print $line | awk '{ print substr($5,1,(length($5)-1))}'`
      fi
      if [[ $prevNAME != $NAME ]]; then
         SERIAL=`print $line | awk '{ print $9;}'`
         NewNAME=`print $NAME | awk '{ print $1":"}'`
         DSKARRAY=`cat $FILE_TWO |
            awk 'BEGIN { FOUND=0 } /'"$NewNAME"'/ { FOUND=1; FLAG=1; } /vpath/ { if (FLAG==0) { FOUND=0 }} { if (FOUND==1) { print $1; FLAG=0; }}'`
        count=0
        FIRSTDSK=0
        for DISK in $DSKARRAY; do
          if [[ $FIRSTDSK -eq 0 ]]; then
            FIRSTDSK=1
          else
            DSK[$count]=$DISK
            count=$(($count + 1))
          fi
        done
        printoutput
     fi
  fi
  prevNAME=$NAME
  read -u3 line
  let Counter=$Counter+1
fi
done
#-----------------------------------------------------------------------
# Removing the temporary file
#-----------------------------------------------------------------------
rm -rf $TEMPFILE
fi

