#!/usr/bin/ksh

##-------------------------------------------------------------------#
## %PS
##    
## Licensed Internal Code - Property of IBM
##    
## 2105 Licensed Internal Code
##    
## (C) Copyright IBM Corp. 1999 All Rights Reserved.
##    
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
## %EPS
##
## COMPONENT_NAME (RAS WUI)
##
##-------------------------------------------------------------------#
##
## Filename: rsList2105s.sh
##
## Subsystem: RAS WUI
##
## Input:	rsList2105s.sh 
##
## Description: Collects host device file names for 2105 disks
##		configured on system.
##
##
## Change History:
##   Modifier               Date                      Change ID
##-------------------------------------------------------------------#
##  Richard Kirchhofer     11-19-1999			28254
##      Initial version
##  Ruth Azevedo           05-31-2000                   
##      Put warning for HP for ESS serial number
##  Ramandeep Kaur         06-12-2000                 36001, 36002
##      Fixed Missing serial number for Sun
##      Fixed allignment of output for Sun
##  Ramandeep Kaur         06-28-2000                    34802
##      Included functionality to get ESS serial numbers 
##      Deleted warning for HP for ESS serial number
##  John Wrobel            08-03-2000                    38511
##      Modifies return codes 
##  Ramandeep Kaur         08-08-2000                    39105
##      Modifies return codes 
##  Susanne Lukas &        11-14-2000                    43080
##  Ramandeep Kaur
##      Included check on datapath output file.  
##-------------------------------------------------------------------#
## End of PROLOG

#--------------------------------------------------------------------#
# Initialization
#--------------------------------------------------------------------#
OS=`uname | cut -c 1-3`
NOHEADER=
DATAFILE=`date | awk '{print "/tmp/"$2"."$3"."$4".rsList2105s.datapath"}'`
SHOWVPATHFILE=`date | awk '{print "/tmp/"$2"."$3"."$4".rsList2105s.showvpath"}'`

export TMP1=/tmp/rsList2105s.tmp1
export TMP2=/tmp/rsList2105s.tmp2

rm -rf $TMP1 $TMP2 /tmp/*.rsList2105s.datapath /tmp/*.rsList2105s.showvpath 

#--------------------------------------------------------------------#
# Look for options
#--------------------------------------------------------------------#
while getopts "n" opt; do
        case $opt in
          n  ) NOHEADER=1
        esac
done
shift $(($OPTIND - 1))


#--------------------------------------------------------------------#
# Setting up INSTALL variable 
#--------------------------------------------------------------------#
if [[ $OS = "AIX" ]]; then
    export INSTALL=/usr/opt/ibm2105cli
fi
if [[ $OS = "Sun" ]]; then
    export INSTALL=/opt/ibm2105cli
    export INSTALLDPO=/opt/IBMdpo/bin
fi
if [[ $OS = "HP-" ]]; then
    export INSTALL=/opt/ibm2105cli
    export INSTALLDPO=/opt/IBMdpo/bin
fi

#--------------------------------------------------------------------#
# Checking If DPO is installed
#--------------------------------------------------------------------#
if [[ $OS = "AIX" ]]; then
  `datapath query device > $DATAFILE 2>/dev/null`
else
  `$INSTALLDPO/datapath query device > $DATAFILE 2>/dev/null`
fi

RC=$?
if [[ $RC -eq 0 ]]; then
 if [[ -s $DATAFILE ]];then
  if [[ $OS = "AIX" || $OS = "HP-" ]]; then
    if [[ -z $NOHEADER ]]; then
       $INSTALL/rsList2105DPO.sh -f $DATAFILE
    else
       $INSTALL/rsList2105DPO.sh -f $DATAFILE -n
    fi
  elif [[ $OS = "Sun" ]]; then
    `$INSTALLDPO/showvpath > $SHOWVPATHFILE 2>/dev/null`
     
    if [[ -z $NOHEADER ]]; then
       $INSTALL/rsList2105DPO.sh -f $DATAFILE -i $SHOWVPATHFILE
    else
       $INSTALL/rsList2105DPO.sh -f $DATAFILE -i $SHOWVPATHFILE -n
    fi
  fi
  rm -rf $DATAFILE $SHOWVPATHFILE
  exit 0
 fi
fi
rm -rf $DATAFILE $SHOWVPATHFILE

##-------------------------------------------------------------------#
## AIX specific code
##-------------------------------------------------------------------#
if [[ $OS = "AIX" ]]; then

##-------------------------------------------------------------------#
## Collect all hdisks defined to system
##-------------------------------------------------------------------#
TEMPDISKS=`lscfg | awk '/hdisk/ { print $2 }' | sort -k 1.6n 2>/dev/null"`

##-------------------------------------------------------------------#
## Determine if hdisk is connected to system
##-------------------------------------------------------------------#
COUNT=0

for DISKNAME in $TEMPDISKS; do
	TYPE=`lscfg -pvl $DISKNAME | sed "s/\./ /g" |
		awk '/Machine Type/ { print $5 }' | cut -c1-4 2>/dev/null"`
	if [[ $TYPE = "2105" ]]; then
		DISKNAMES[$COUNT]=$DISKNAME
		DISKS[$COUNT]=`lscfg -pvl $DISKNAME | 
			sed "s/\./ /g" | 
			awk '/Serial Number/ { print $3 }' 2>/dev/null"`
        	COUNT=$(($COUNT + 1))
	fi

done

fi

##-------------------------------------------------------------------#
## Sun specific code
##-------------------------------------------------------------------#
if [[ $OS = "Sun" ]]; then

##-------------------------------------------------------------------#
## Collect device information
##-------------------------------------------------------------------#
echo "disk\n0\nquit" >$TMP1
format -f $TMP1 -l $TMP2 1>/dev/null 2>/dev/null

##-------------------------------------------------------------------#
## Collect device file names
##-------------------------------------------------------------------#
TEMPNAMES=`cat $TMP2 | awk '/IBM-2105/ { print $2 }' | sed "s/\.//g"`

COUNT=0
for DISKNAME in $TEMPNAMES; do
	DISKNAMES[$COUNT]=$DISKNAME
        COUNT=$(($COUNT + 1))
done

##-------------------------------------------------------------------#
## Collect 2105 serial numbers
##-------------------------------------------------------------------#
TEMPDISKS=`cat $TMP2 | awk '/IBM-2105/ { print $1 }' | sed "s/\.//g"`

COUNT=0
for DISKNUMBER in $TEMPDISKS; do
	echo "$DISKNUMBER\nscsi\ninquiry" >$TMP1
	format -e 0<$TMP1 1>/dev/null 2>$TMP2
	X="cat $TMP2 |
		awk 'BEGIN { FOUND=0 } { if (FOUND > 0) { print \$0; exit } } /2105/ { FOUND=1 }' |
		awk '{ print \$17 }' |
		cut -c 5-12"
	DISKS[$COUNT]=`eval $X`
        COUNT=$(($COUNT + 1))
done

fi

##-------------------------------------------------------------------#
## HP specific code
##-------------------------------------------------------------------#
if [[ $OS = "HP-" ]]; then

##-------------------------------------------------------------------#
## Collect device information
##-------------------------------------------------------------------#
ioscan -fnC disk >$TMP2 2>/dev/null

##-------------------------------------------------------------------#
## Collect device file names
##-------------------------------------------------------------------#
TEMPNAMES=`cat $TMP2 | 
	awk 'BEGIN { FOUND=0 } { if (FOUND==1) { print $1; FOUND=0 }} / 2105/ { FOUND=1 }' |
        awk '{ print $1 }' | sed "s/dsk/rdsk/g"`

COUNT=0

##-------------------------------------------------------------------#
## Collect 2105 serial numbers 
##-------------------------------------------------------------------#
OSVERSION=`uname -a | awk '{print $3}'`

if [[ $OSVERSION = "B.11.00" ]]; then
  export INQUIRY=$INSTALL/bin.HP/rsInquiryHP11.exe
elif [[ $OSVERSION = "B.10.20" ]]; then
  export INQUIRY=$INSTALL/bin.HP/rsInquiryHP10.exe
else
  echo "Command Line Interface is not supported for HP-UX Version $OSVERSION"
  exit 80
fi

for DISKNAME in $TEMPNAMES; do
        SNO=`$INQUIRY $DISKNAME`
        RC=$? 
        if [[ $RC -eq 0 ]]; then
	  DISKNAMES[$COUNT]=`print $DISKNAME | awk -F\/ '{ print $4 }'`
          DISKS[$COUNT]=$SNO
          COUNT=$(($COUNT + 1))
        fi
done
fi

##-------------------------------------------------------------------#
## Display infomation
##-------------------------------------------------------------------#
LINE=0

if [[ -z $NOHEADER ]]; then
	if [[ $COUNT -eq 0 ]]; then
		echo "No 2105 volumes found"
		exit 13
	fi
	echo "disk name\t2105 serial number"
	echo "---------\t------------------"
else
	if [[ $COUNT -eq 0 ]]; then
		exit 13
	fi
fi


while [[ $LINE -ne $COUNT ]]; do
	if [[ -z $NOHEADER ]]; then
                if [[ ${DISKS[$LINE]} = "" ]]; then
                        DISKS[$LINE]='NoSerialNumberFound'
                fi

		if [[ $OS = "AIX" ]]; then
			DISK=${DISKNAMES[$LINE]}
			if [[ ${#DISK} > 6 ]]; then
                           echo " ${DISKNAMES[$LINE]}\t   ${DISKS[$LINE]}" 
			else
                           echo " ${DISKNAMES[$LINE]}\t\t   ${DISKS[$LINE]}"
			fi
                else
                        DISK=${DISKNAMES[$LINE]}
                        if [[ ${#DISK} > 6 ]]; then
                           printf " %s           %s\n" ${DISKNAMES[$LINE]} ${DISKS[$LINE]}
                        else
                           printf " %s            %s\n" ${DISKNAMES[$LINE]} ${DISKS[$LINE]}
                        fi
	        fi
	else 
                if [[ ${DISKS[$LINE]} != "" ]]; then
                  echo "${DISKNAMES[$LINE]}"
		      echo "${DISKS[$LINE]}"
                fi
	fi
	LINE=$(($LINE + 1))
done

##-------------------------------------------------------------------#
## Clean-up
##-------------------------------------------------------------------#
rm -rf $TMP1 $TMP2

##-------------------------------------------------------------------#
## Quit
##-------------------------------------------------------------------#
exit 0
