#!/usr/bin/ksh

##-------------------------------------------------------------------#
## %PS
##    
## Licensed Internal Code - Property of IBM
##    
## 2105 Licensed Internal Code
##    
## (C) Copyright IBM Corp. 1999 All Rights Reserved.
##    
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
## %EPS
##
## COMPONENT_NAME (RAS WUI)
##
## Function: rsQuery.sh
##
##-------------------------------------------------------------------#
##
## Filename: rsQuery.sh
##
## Subsystem: RAS WUI
##
## Input:	rsQuery.sh -v -m -u username -p password -a securityfilepath -f filename -q volume -s server -b backup_server 
##
##              -v = verbose
##		-f = name of file containing pairs of volume 
##		     serial numbers
##		-m = map disk names to 2105 volume serial numbers
##		-q = volume
##		-u = username
##		-p = password
##              -a = securityfilepath
##              -s = name of copy services server 
##              -b = name of backup copy services server 
##
## Description: Query the status of one or more volumes
##
##
## Change History:
##   Modifier               Date                             Change ID
##-------------------------------------------------------------------#
##  Richard Kirchhofer     10/19/1999			     26532
##      Initial version
##  Richard Kirchhofer     12/03/1999			     28254
##      Modifications for HP and SUN
##  Richard Kirchhofer     04 Feb 2000				29810
##      Standalone ORB conversion
##  Anne Chau              02-18-2000                          31101
##      Packaging simplification..call rsENV to setup INSTALL & JAVA_HOME
##  Anne Chau              03-08-2000                          32263
##      CLI function rsTestConnection does not work
##  Ruth E. Azevedo        05-30-2000                          34871
##      Modify INSTALL directory for AIX  and HP        
##  Ruth E. Azevedo        05-30-2000                          35799
##      Replace -e test to -f for existance of a file    
##  Ramandeep Kaur         06-07-2000                          35593
##      Included the checking of format of input file
##      changed some error messages
##  Ramandeep Kaur         06-14-2000                          35982
##      Fixed awk command
##  Ramandeep Kaur         06-28-2000                      35050
##      changed iioprt.zip to iioprt.jar
##  John Wrobel            07-21-2000                          38511
##      Modified return codes
##  John Wrobel            07-21-2000                          38510
##      Test connection to primary/backup server
##      Primary and Backup server parameters added to command line
##  Ramandeep Kaur         08-08-2000	        	         39105
##      Modified return codes, flags, and awk statement
##  Ramandeep Kaur         10-05-2000                          41892
##      Added the functionality of giving Backup
##      server by itself
##  Brian McCain           10-14-2000                          41890
##      Modified error checking to catch bad parameters
##  Ramandeep Kaur         10-19-2000                          42290
##      Modified env variable CLASSPATH
##  Brian McCain           10-20-2000                          43123
##      Display usage if no parameters specified
##  Ramandeep Kaur         11-02-2000                          43575
##      Added /a flag
##  Ramandeep Kaur         11-14-2000                      43880
##      Included check if user gave space between - and flag
##-------------------------------------------------------------------#
## End of PROLOG

OS=`uname | cut -c 1-3`
##-------------------------------------------------------------------#
## Set defaults
##-------------------------------------------------------------------#
BINDIR=/usr/lpp/searas/bin
SERVERNAME=
PRIMARY_SERVER=
BACKUP_SERVER=
FILENAME=
USERNAME=
PASSWORD=
FILEPATH=
VOLUME=
MAP=
OPTIONS=
RC=

TMP1=/tmp/rsQuery.tmp

##-------------------------------------------------------------------#
## AIX specific code to set up INSTALL and JAVA_HOME
##-------------------------------------------------------------------#
if [[ $OS = "AIX" ]]; then

export INSTALL=/usr/opt/ibm2105cli
export JAVA_HOME=/usr/jdk_base

fi
##-------------------------------------------------------------------#
## Sun specific code
##-------------------------------------------------------------------#
if [[ $OS = "Sun" ]]; then

export INSTALL=/opt/ibm2105cli
export JAVA_HOME=/usr/java

fi
##-------------------------------------------------------------------#
## HP specific code
##-------------------------------------------------------------------#
if [[ $OS = "HP-" ]]; then

export INSTALL=/opt/ibm2105cli
export JAVA_HOME=/opt/java

fi

##-------------------------------------------------------------------#
## Process arguments
##-------------------------------------------------------------------#
USAGE='usage: rsQuery.sh [-v] -m -u username & -p password | -a securityfilepath -f filename|-q volume -s primaryserver -b backupserver'

if [[ -z $1 ]]; then
    echo "rsQuery: No parameters specified"
    echo $USAGE
    exit 21
fi

while getopts ":vmf:u:p:s:b:q:a:" opt; do
        if [[ $OPTARG = -* ]]; then
           echo "rsQuery: Missing argument for -$opt"
           echo $USAGE
           exit 20
        fi
        case $opt in
          v  ) OPTIONS="-v";;
          f  ) FILENAME=$OPTARG;;
          m  ) MAP=1;;
          u  ) USERNAME=$OPTARG;;
          p  ) PASSWORD=$OPTARG;;
	  a  ) FILEPATH=$OPTARG;;
          s  ) PRIMARY_SERVER=$OPTARG;;
          b  ) BACKUP_SERVER=$OPTARG;;
          q  ) VOLUME=$OPTARG;;
          \? ) echo "rsQuery: Invalid parameter specified"
               echo $USAGE
               exit 19
        esac
done
shift $(($OPTIND - 1))

while [[ ! -z $1 ]];do
    if [[ $1 = - ]]; then
         echo "rsQuery: Invalid parameter specified"
         echo $USAGE
         exit 19
    fi
done

if [[ -z $PRIMARY_SERVER && -z $BACKUP_SERVER ]]; then
        echo "rsQuery: No primary or backup server name specified"
        exit 3
fi

if [[ -z $VOLUME && -z $FILENAME ]]; then
	echo "rsQuery: Missing parameters"
	exit 10 
fi

if [[ ! -z $VOLUME && ! -z $FILENAME ]]; then
	echo "rsQuery: Conflicting parameters"
	exit 15 
fi

if [[ -z $VOLUME ]]; then
	if [[ -z $FILENAME ]]; then
		echo "rsQuery: Volume list not specified"
		exit 14 
	fi

	if [[ ! -f $FILENAME ]]; then
		echo "rsQuery: Volume list file $FILENAME does not exist"
		exit 17 
	fi
fi

if [[ ! -z  $FILEPATH ]];then
  if  [[ ! -a $FILEPATH ]];then
     echo "rsExecuteTask: security file $FILEPATH could not be found"
     exit 23
  fi
  if [[ ! -s $FILEPATH ]];then
     echo "rsExecuteTask: format of security file $FILEPATH is incorrect"
     exit 24
  fi
fi

OPT_USERNAME=${USERNAME:+"-u $USERNAME"}
OPT_PASSWORD=${PASSWORD:+"-p $PASSWORD"}
OPT_FILEPATH=${FILEPATH:+"-a $FILEPATH"}

##-------------------------------------------------------------------#
## Set-up environmental variables
##-------------------------------------------------------------------#
export CLASSPATH=.:$INSTALL/ibmjbrt.zip:$INSTALL/iioprt.jar:$INSTALL/omg-1.1.zip:$INSTALL/JavaRAS_1_0.zip:$INSTALL/rsCopyServices.jar:$JAVA_HOME/lib/classes.zip:$CLASSPATH
export PATH=$INSTALL:$JAVA_HOME/bin:$PATH
export LIBPATH=$INSTALL:/usr/lib

##-------------------------------------------------------------------#
## Test Connections if only Primary Server is given
##-------------------------------------------------------------------#
if [[ ! -z $PRIMARY_SERVER && -z $BACKUP_SERVER ]];then
   SNAME="-Server=$PRIMARY_SERVER"
   $JAVA_HOME/bin/java rsCopyServices.rsWebTest $SNAME 2>&1 > /dev/null
   RC=$?
   if [[ $RC -ne 0 ]];then
      echo "rsQuery: The primary server is down and there is no backup server specified."
      echo "         The task is not completed."
      exit 41
   elif [[ $RC -eq 0 ]]; then
      SERVERNAME=$PRIMARY_SERVER
   fi
fi

##-------------------------------------------------------------------#
## Test Connections if only Backup Server is given
##-------------------------------------------------------------------#
if [[ -z $PRIMARY_SERVER && ! -z $BACKUP_SERVER ]];then
   SNAME="-Server=$BACKUP_SERVER"
   $JAVA_HOME/bin/java rsCopyServices.rsWebTest $SNAME 2>&1 > /dev/null
   RC=$?
   if [[ $RC -ne 0 ]];then
      echo "rsQuery: The backup server is down and there is no primary server specified."
      echo "         The task is not completed."
      exit 45
   elif [[ $RC -eq 0 ]]; then
      SERVERNAME=$BACKUP_SERVER
   fi
fi

##-------------------------------------------------------------------#
## Test Connections if both of Primary  and Backup Server is given
##-------------------------------------------------------------------#
if [[ ! -z $PRIMARY_SERVER && ! -z $BACKUP_SERVER ]];then
   SNAME="-Server=$PRIMARY_SERVER"
   $JAVA_HOME/bin/java rsCopyServices.rsWebTest $SNAME 2>&1 > /dev/null
   RC=$?

   if [[ $RC -ne 0 ]]; then
        if [[ ! -z $OPTIONS ]]; then
           echo "rsQuery: The primary server is down, trying the specified backup server ..."
        fi
        SNAME="-Server=$BACKUP_SERVER"
        $JAVA_HOME/bin/java rsCopyServices.rsWebTest $SNAME 2>&1 > /dev/null
        RC=$?
        if [[ $RC -ne 0 ]]; then
           echo "rsQuery: The primary and backup server are down.  The task not completed."
           exit 42
        elif [[ $RC -eq 0 ]]; then
           if [[ ! -z $OPTIONS ]]; then
             echo "rsQuery: The task will be run off the backup server."
           fi
           SERVERNAME=$BACKUP_SERVER
        fi
    elif [[ $RC -eq 0 ]]; then
      SERVERNAME=$PRIMARY_SERVER
    fi
fi

OPT_SERVERNAME=${SERVERNAME:+"-s $SERVERNAME"}
##-------------------------------------------------------------------#
## Get mapping of all disks
##-------------------------------------------------------------------#
if [[ ! -z $MAP ]]; then
	$INSTALL/rsList2105s.sh >$TMP1
fi

##-------------------------------------------------------------------#
## Checking if the input file has the right format
##-------------------------------------------------------------------#
if [[ ! -z $FILENAME ]]; then
  {
     while read SRC TARG EXTRA ; do
       if [[ $EXTRA != "" ]]; then
         echo "rsQuery: more volume/s per line "
         exit 16
       fi
    done
  } < $FILENAME
fi

##-------------------------------------------------------------------#
## Call Query command for each volume specified
##-------------------------------------------------------------------#
if [[ ! -z $FILENAME ]]; then

	VOLUMELIST=`cat $FILENAME | awk '!/#/ { print $1; print $2 }'`
	ALLVOLUMES=

      
	for VOLUME in $VOLUMELIST; do

		if [[ ! -z $MAP ]]; then
			X="cat $TMP1 | awk '\$1 ~ /$VOLUME/ { print \$2; exit}'"
			CVOLUME=`eval $X`
			if [[ ! -z $CVOLUME ]]; then 
				VOLUME=$CVOLUME
			fi
		fi

        	ALLVOLUMES="$ALLVOLUMES $VOLUME"
	done

      $JAVA_HOME/bin/java rsCopyServices.rsQuery $OPTIONS $OPT_USERNAME $OPT_PASSWORD $OPT_FILEPATH $OPT_SERVERNAME $ALLVOLUMES

else
	if [[ ! -z $MAP ]]; then
		X="cat $TMP1 | awk '\$1 ~ /$VOLUME/ { print \$2; exit}'"
		CVOLUME=`eval $X`
		if [[ ! -z $CVOLUME ]]; then 
			VOLUME=$CVOLUME
		fi
	fi
        $JAVA_HOME/bin/java rsCopyServices.rsQuery $OPTIONS $OPT_USERNAME $OPT_PASSWORD $OPT_FILEPATH $OPT_SERVERNAME $VOLUME

fi

##-------------------------------------------------------------------#
## Quit
##-------------------------------------------------------------------#
RC=$?
exit $RC 
