#!/usr/bin/ksh

##-------------------------------------------------------------------#
## %PS
##    
## Licensed Internal Code - Property of IBM
##    
## 2105 Licensed Internal Code
##    
## (C) Copyright IBM Corp. 1999 All Rights Reserved.
##    
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
## %EPS
##
## COMPONENT_NAME (RAS WUI)
##
##-------------------------------------------------------------------#
##
## Filename: rsTestConnection.sh
##
## Subsystem: RAS WUI
##
## Input:	rsTestConnection.sh -v -s serverName
##
##		-v = verbose mode 
##		-s = name of copy services server
##
## Description: Test whether the Copy Services Server can be reached
##
##
## Change History:
##   Modifier               Date                      Change ID
##-------------------------------------------------------------------#
##  Richard Kirchhofer     12-11-1999			27625
##      Initial version
##  Richard Kirchhofer     04 Feb 2000			29810
##      Standalone ORB conversion
##  Anne Chau              02-18-2000                          31101
##      Packaging simplification..call rsENV to setup INSTALL & JAVA_HOME
##  Anne Chau              03-08-2000                          32263
##      CLI function rsTestConnection does not work
##  Ruth E. Azevedo        05-30-2000                          34871
##      Modify INSTALL directory for AIX, SUN and HP
##  Ramandeep Kaur         06-28-2000                      35050
##      changed iioprt.zip to iioprt.jar
##  John Wrobel            07-24-2000                    38510
##      Added servername parameter to command line                       
##  John Wrobel            08-17-2000                        39576 
##      Changed -v flag with -Verbose=yes  
##  Ramandeep Kaur         10-04-2000                        41886                  
##      Took out the username and password flags
##  Ruth E. Azevedo        10-04-2000                        41886                  
##      Modify getops so that it prints meaningful message
##  Ramandeep Kaur         10-19-2000                        42290
##      Modified env variable CLASSPATH
##  Brian McCain           10-20-2000                        43123
##      Display usage if no parameters specified
##  Ramandeep Kaur         11-13-2000                        43880
##      Included check if user gave space between - and flag 
##-------------------------------------------------------------------#
## End of PROLOG

OS=`uname | cut -c 1-3`
##-------------------------------------------------------------------#
## Set defaults
##-------------------------------------------------------------------#
SERVERNAME=
OPTIONS=
RC=

##-------------------------------------------------------------------#
## AIX specific code to set up INSTALL and JAVA_HOME
##-------------------------------------------------------------------#
if [[ $OS = "AIX" ]]; then

export INSTALL=/usr/opt/ibm2105cli
export JAVA_HOME=/usr/jdk_base

fi
##-------------------------------------------------------------------#
## Sun specific code
##-------------------------------------------------------------------#
if [[ $OS = "Sun" ]]; then

export INSTALL=/opt/ibm2105cli
export JAVA_HOME=/usr/java

fi
##-------------------------------------------------------------------#
## HP specific code
##-------------------------------------------------------------------#
if [[ $OS = "HP-" ]]; then

export INSTALL=/opt/ibm2105cli
export JAVA_HOME=/opt/java

fi

##-------------------------------------------------------------------#
## Process arguments
##-------------------------------------------------------------------#
USAGE='usage: rsTestConnection.sh -v -s primaryserver'

if [[ -z $1 ]]; then
     echo "rsTestConnection: No parameters specified"
     echo $USAGE
     exit 21
fi

while getopts ":vs:" opt; do
        case $opt in
          s  ) SERVERNAME=$OPTARG;;
	  v  ) OPTIONS="-Verbose=yes";;
	  \? ) echo "rsTestConnection: Invalid parameter specified"
               echo $USAGE
	       exit 19
        esac
done
shift $(($OPTIND - 1))

while [[ ! -z $1 ]];do
    if [[ $1 = - ]]; then
         echo "rsTestConnection: Invalid parameter specified"
         echo $USAGE
         exit 19
    fi
done

if [[ -z $SERVERNAME ]]; then
	echo "rsTestConnection: Server name not specified"
	exit 3 
fi

SERVERNAME="-Server=$SERVERNAME"

##-------------------------------------------------------------------#
## Set-up environmental variables
##-------------------------------------------------------------------#
export CLASSPATH=.:$INSTALL/ibmjbrt.zip:$INSTALL/iioprt.jar:$INSTALL/omg-1.1.zip:$INSTALL/JavaRAS_1_0.zip:$INSTALL/rsCopyServices.jar:$JAVA_HOME/lib/classes.zip:$CLASSPATH
export PATH=$INSTALL:$JAVA_HOME/bin:$PATH
export LIBPATH=$INSTALL:/usr/lib

##-------------------------------------------------------------------#
## Call WebTest command
##-------------------------------------------------------------------#
$JAVA_HOME/bin/java rsCopyServices.rsWebTest $OPTIONS $SERVERNAME
RC=$?
	
##-------------------------------------------------------------------#
## Quit
##-------------------------------------------------------------------#
exit $RC
