/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.io.*;
import java.util.*;

/**
 * <code>RASFileHandler</code> implements a <code>RASHandler</code> 
 * that writes to a file.  The name of the file must be specified
 * in the constructor or through the <code>setFileName</code> method,
 * as no default name exists.
 *
 * @see RASHandler
 */

public class RASFileHandler extends RASHandler
{
private static final String S = RASCopyright.COPYRIGHT_98;

/**
 * The name of the file to which the log entries are written.
 */

private String fileName = null;


/*----------------------------------------------------------------------
 * Name:  RASFileHandler
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASFileHandler</code>.  The name and
 * description of this object are empty strings.
 */

public RASFileHandler() 
{
this("", "");
}


/*----------------------------------------------------------------------
 * Name:  RASFileHandler
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASFileHandler</code>.  The description
 * of this object is an empty string.
 *
 * @param name The name of this object.
 */

public RASFileHandler(String name) 
{
this(name, "");
}


/*----------------------------------------------------------------------
 * Name:  RASFileHandler
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASFileHandler</code>.
 *
 * @param name The name of this object.
 * @param desc The description of this object.
 */

public RASFileHandler(String name, String desc) 
{
super(name, desc);
}


/*----------------------------------------------------------------------
 * Name:  RASFileHandler
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASFileHandler</code>.
 *
 * @param name The name of this object.
 * @param desc The description of object.
 * @param file The name of the output file.
 */

public RASFileHandler(String name, String desc, String file) 
{
this(name, desc);
setFileName(file);
}


/*----------------------------------------------------------------------
 * Name:  getConfig
 *--------------------------------------------------------------------*/
/**
 * Gets the configuration of this object.
 *
 * @return A <code>Hashtable</code> containing the configuration.
 *         This object inserts the following key/value pairs into the
 *         configuration:
 *         <pre>
 *         "fileName" The name of the output file.
 *         </pre>
 *         All values are <code>Strings</code>.
 *         The parent and extensions of this object may add additional keys.
 **/

public Hashtable getConfig()
{
Hashtable ht = super.getConfig();

ht.put("fileName", getFileName());

return ht;
}


/*----------------------------------------------------------------------
 * Name:  setConfig
 *--------------------------------------------------------------------*/
/**
 * Sets the configuration of this object.  This method is used by a 
 * <code>RASManager</code> to initialize a RAS object.  It should not 
 * be necessary for an application to use this method.
 *
 * @param ht  A <code>Hashtable</code> containing the configuration.
 *            This object searches for the following keys:
 *            <pre>
 *            "fileName" The name of the output file.
 *            </pre>
 *            All values are <code>Strings</code>.
 *            If a key is not found, that configuration element is not
 *            updated.
 *            The parent and extensions of this logger may use additional keys.
 **/

public void setConfig(Hashtable ht)
{
super.setConfig(ht);
if (ht.containsKey("fileName"))
  setFileName((String) ht.get("fileName"));
}


/*----------------------------------------------------------------------
 * Name:  getFileName
 *--------------------------------------------------------------------*/
/**
 * Gets the name of the file used by this handler.
 *
 * @return The name of the output file.  If no file name has been set,
 *         <code>null</code> is returned.
 **/

public String getFileName()
{
return fileName;
}


/*----------------------------------------------------------------------
 * Name:  setFileName
 *--------------------------------------------------------------------*/
/**
 * Sets the name of the file used by this handler.  If the file name is
 * null, this current file name is not changed.
 *
 * @param name The name of the output file.
 **/

public void setFileName(String name)
{
if (name != null)
  fileName = name;
}


/*----------------------------------------------------------------------
 * Name:  openDevice
 *--------------------------------------------------------------------*/
/**
 * Opens the device to which the handler will send its log entries.
 * If an error occurs during this process, the handler will write a
 * message to <code>System.err</code>.
 * <p>
 * The caller should ensure that this method is not called if the device
 * is already open or if cannot tolerate attempts to reopen it.
 * <p>
 * For the <code>RASFileHandler</code>, the device is the file 
 * named on the constructor or through the <code>setFileName</code>
 * method.  New log entries are appended to the file, if it already exists.
 * If the file name is changed via <code>setFileName</code>, this method
 * must be called again to open the new file.
 **/

public void openDevice()
{
try
  {
  pWriter = new PrintWriter(new FileWriter(getFileName(), true), true);
  deviceOpen = true;
  }
catch (Exception e)
  {
  System.err.println(RASUtil.rasMsgs.getMessage("ERR_OPEN_FILE", getFileName()));
  }
}

}
