/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.io.Serializable;
import java.util.Hashtable;

/**
 * <code>RASIEvent</code> defines the methods that must be implemented
 * to contain RAS message or trace data.
 * Within the RAS Toolkit, <code>RASIEvent</code> is implemented by
 * the <code>RASEvent</code> class.
 *
 * @see RASEvent
 */

public interface RASIEvent extends Serializable
{

/*----------------------------------------------------------------------
 * Name:  getTimeStamp
 *--------------------------------------------------------------------*/
/**
 * Gets the time at which this event was created.
 * 
 * @param timeStamp The event time stamp, as generated by 
 *                  <code>System.currentTimeMillis</code>.
 **/

public long getTimeStamp();


/*----------------------------------------------------------------------
 * Name:  setTimeStamp
 *--------------------------------------------------------------------*/
/**
 * Sets the time at which this event was created.  This value is 
 * expected to be of the format returned by 
 * <code>System.currentTimeMillis</code>.
 * 
 * @param timeStamp The event time stamp.
 **/

public void setTimeStamp(long timeStamp);


/*----------------------------------------------------------------------
 * Name:  getType
 *--------------------------------------------------------------------*/
/**
 * Gets the type of event:  "informational message," for example.
 * Specific types are defined by the classes which extend <code>RASEvent</code>.
 * 
 * @return The event type.
 **/

public long getType();


/*----------------------------------------------------------------------
 * Name:  setType
 *--------------------------------------------------------------------*/
/**
 * Sets the type of event:  "informational message," for example.
 * Specific types are defined by the classes which extend <code>RASEvent</code>.
 * 
 * @param type The event type.
 **/

public void setType(long type);


/*----------------------------------------------------------------------
 * Name:  getText
 *--------------------------------------------------------------------*/
/**
 * Gets the event text.
 * 
 * @return The event text.

 **/

public String getText();


/*----------------------------------------------------------------------
 * Name:  setText
 *--------------------------------------------------------------------*/
/**
 * Sets the event text.
 * 
 * @param text The event text.
 **/

public void setText(String text);


/*----------------------------------------------------------------------
 * Name:  getParameters
 *--------------------------------------------------------------------*/
/**
 * Gets the text parameters:  <code>Strings</code> to be displayed with
 * the message text.
 * 
 * @return The text parameters.
 **/

public String[] getParameters();


/*----------------------------------------------------------------------
 * Name:  setParameters
 *--------------------------------------------------------------------*/
/**
 * Gets the text parameters:  <code>Strings</code> to be displayed with
 * the message text.
 * 
 * @param parms The text parameters.
 **/

public void setParameters(String[] parms);


/*----------------------------------------------------------------------
 * Name:  getAttribute
 *--------------------------------------------------------------------*/
/**
 * Gets an attribute that is saved as part of a RAS event.
 * 
 * @param name The name of the attribute. 
 * 
 * @return The attribute associated with the name or <code>null</code> 
 *         if the named attribute was not found.
 **/

public Object getAttribute(String name);


/*----------------------------------------------------------------------
 * Name:  setAttribute
 *--------------------------------------------------------------------*/
/**
 * Sets an attribute, saving it as part of a RAS event.  If the name or 
 * the attribute are <code>null</code>, nothing is saved.
 * 
 * @param name   The name of the attribute. 
 * @param attrib The attribute associated with the name.
 **/

public void setAttribute(String name, Object attrib);


/*----------------------------------------------------------------------
 * Name:  setMessageEvent
 *--------------------------------------------------------------------*/
/**
 * Sets a flag that that indicates whether this object is classified 
 * as a message event or a trace event.
 *
 * @param flag A <code>boolean</code> set <code>true</code> if this
 *             object is a message event and <code>false</code> if it
 *             is a trace event.
 **/

public void setMessageEvent(boolean flag);


/*----------------------------------------------------------------------
 * Name:  isMessageEvent
 *--------------------------------------------------------------------*/
/**
 * Determines if this object is a message event or a trace event.
 *
 * @return <code>true</code> if this object is a message event and 
 *         <code>false</code> if it is a trace event.
 **/

public boolean isMessageEvent();


/*----------------------------------------------------------------------
 * Name:  getSupportedTypes
 *--------------------------------------------------------------------*/
/**
 * Gets the complete set of event types supported by this class.
 * <p>
 * This method can be used by a graphical log manager to display the 
 * set of types and allow a user to select those to be monitored.  Every
 * extending class should override this method to add the types it supports
 * to the <code>Hashtable</code> returned by its parent.
 *
 * @return A <code>Hashtable</code> containing the values of all of the
 *         event types.  The names of the types are used as keys and
 *         are returned in the current locale.  The type values,
 *         normally kept as <code>ints</code>, are returned as
 *         <code>Integers</code> because of the <code>Hashtable</code>
 *         requirement that all elements be <code>Objects</code>.
 */

public Hashtable getSupportedTypes();
}
