/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.util.*;

/**
 * <code>RASIFormatter</code> defines the methods that must be implemented
 * to format RAS events.  Within the RAS Toolkit, <code>RASIFormatter</code> 
 * is implemented by the <code>RASFormatter</code> class.
 *
 * @see RASFormatter
 */

public interface RASIFormatter extends RASIObject
{

/*----------------------------------------------------------------------
 * Name:  addEventClass
 *--------------------------------------------------------------------*/
/**
 * Adds the name of a <code>RASIEvent</code> class which this formatter
 * can process. If the event class is <code>null</code> or is already 
 * registered, this method does nothing.
 *
 * @param name The event class name.
 */

public void addEventClass(String name);


/*----------------------------------------------------------------------
 * Name:  removeEventClass
 *--------------------------------------------------------------------*/
/**
 * Removes the name of a <code>RASIEvent</code> class from the list of
 * classes which this formatter can process. If the event class is 
 * <code>null</code> or is not registered, this method does nothing.
 *
 * @param name The event class name.
 */

public void removeEventClass(String name);


/*----------------------------------------------------------------------
 * Name:  getEventClasses
 *--------------------------------------------------------------------*/
/**
 * Gets the set of <code>RASIEvent</code> classes which this formatter
 * can process.
 *
 * @return An <code>Enumeration</code> of RAS event class names.  If
 *         no event classes are registered, the <code>Enumeration</code>
 *         is empty.
 */

public Enumeration getEventClasses();


/*----------------------------------------------------------------------
 * Name:  format
 *--------------------------------------------------------------------*/
/**
 * Formats the RAS event.
 * 
 * @param event The event to format.
 * 
 * @return The formatted event.
 **/

public String format(RASIEvent event);
}
