/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.util.*;

/**
 * <code>RASILogger/code> defines the methods which are common to 
 * objects that wish to create RAS message and trace data.  This interface 
 * is intended to be extended to include methods specific to the creation
 * of message or trace data and should not be implemented directly.
 * <p>
 * <I>An object which implements this interface may also wish to 
 * implement <code>RASIMaskChangeListener</code>.
 *
 * @see RASIMessageLogger
 * @see RASITraceLogger
 */

public interface RASILogger extends RASIObject
{

/*----------------------------------------------------------------------
 * Name:  getConfig
 *--------------------------------------------------------------------*/
/**
 * Gets the configuration of this object.
 *
 * @return A <code>Hashtable</code> containing the configuration.
 *         This object inserts the following key/value pairs into the
 *         configuration:
 *         <pre>
 *         "isLogging" "true" if the logger is logging data; 
 *                     otherwise, "false".
 *         "isSync"    "true" if the logger is logging
 *                     synchronously; otherwise, "false".
 *         "server"    The server.
 *         "client"    The client.
 *         </pre>
 *         All values are <code>Strings</code>.
 *         The parent and extensions of this object may add additional keys.
 **/

public Hashtable getConfig();


/*----------------------------------------------------------------------
 * Name:  setConfig
 *--------------------------------------------------------------------*/
/**
 * Sets the configuration of this object.  This method is used by a 
 * <code>RASManager</code> to initialize a RAS object.  It should not 
 * be necessary for an application to use this method.
 *
 * @param ht  A <code>Hashtable</code> containing the configuration.
 *            This object searches for the following keys:
 *            <pre>
 *            "isLogging" "true" if the logger is logging data; 
 *                        otherwise, "false".
 *            "isSync"    "true" if the logger is logging
 *                        synchronously; otherwise, "false".
 *            "server"    The server.
 *            "client"    The client.
 *            </pre>
 *            All values are <code>Strings</code>.
 *            If a key is not found, that configuration element is not
 *            updated.
 *            The parent and extensions of this object may use additional keys.
 **/

public void setConfig(Hashtable ht);


/*----------------------------------------------------------------------
 * Name:  addHandler
 *--------------------------------------------------------------------*/
/**
 * Registers a RAS handler with this logger.  More than one handler
 * may be associated with a logger to direct the RAS data to multiple
 * destinations.  If the handler is <code>null</code> or is already 
 * registered, this method does nothing.
 *
 * @param handler A RAS handler.
 **/

public void addHandler(RASIHandler handler);


/*----------------------------------------------------------------------
 * Name:  removeHandler
 *--------------------------------------------------------------------*/
/**
 * Removes a RAS handler from this logger.  If the handler is 
 * <code>null</code> or is not registered, this method does nothing.
 * 
 * @param handler A RAS handler.
 **/

public void removeHandler(RASIHandler handler);


/*----------------------------------------------------------------------
 * Name:  getHandlers
 *--------------------------------------------------------------------*/
/**
 * Gets all of the handlers associated with this logger.
 *
 * @return An <code>Enumeration</code> of handlers.  If no handlers
 *         are registered, the <code>Enumeration</code> is empty.
 **/

public Enumeration getHandlers();


/*----------------------------------------------------------------------
 * Name:  setSynchronous
 *--------------------------------------------------------------------*/
/**
 * Sets a flag that tells the logger whether to log data synchronously.
 * When logging synchronously, the logger will wait for the handlers
 * to write a log entry before returning to the caller.  Otherwise,
 * the log entry is passed to the handler and the logger returns.
 *
 * @param flag A <code>boolean</code> set <code>true</code> for 
 *             synchronous logging and <code>false</code> otherwise.
 **/

public void setSynchronous(boolean flag);


/*----------------------------------------------------------------------
 * Name:  isSynchronous
 *--------------------------------------------------------------------*/
/**
 * Determines if synchronous logging is in effect.
 * When logging synchronously, the logger will wait for the handlers
 * to write a log entry before returning to the caller.  Otherwise,
 * the log entry is passed to the handler and the logger returns.
 *
 * @return <code>true</code> for synchronous logging and 
 *         <code>false</code> otherwise.
 **/

public boolean isSynchronous();


/*----------------------------------------------------------------------
 * Name:  isLoggable
 *--------------------------------------------------------------------*/
/**
 * Determines if a log entry will be processed by the logger and any of
 * the handlers.  Wrapping a message or trace call with this method can
 * improve performance.  Log entries that will not be processed need not
 * even be built.  For example:
 * <pre>
 * if (isLoggable(RASTraceEvent.TYPE_PUBLIC)
 *   trace(RASTraceEvent.TYPE_PUBLIC...);
 * </pre>
 *
 * @param type The type of the log entry.  The set of possible values is
 *             defined by the <code>RASMessageEvent</code> or 
 *             <code>RASITraceEvent TYPE_XXXX</code> constants.
 *
 * @return <code>true</code> if the logger is enabled and at least one
 *         handler will process the log entry; <code>false</code>, 
 *         otherwise.
 */

public boolean isLoggable(long type);
}
