/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.util.*;

/**
 * <code>RASIMessageLogger</code> defines a set of methods that must be 
 * implemented to create RAS messages.
 *
 * @see RASILogger
 * @see RASMessageLogger
 */

public interface RASIMessageLogger extends RASILogger
{

/*----------------------------------------------------------------------
 * Name:  getConfig
 *--------------------------------------------------------------------*/
/**
 * Gets the configuration of this object.
 *
 * @return A <code>Hashtable</code> containing the configuration.
 *         This object inserts the following key/value pairs into the
 *         configuration:
 *         <pre>
 *         "messageMask"    The mask which selects the message types to
 *                          be processed.
 *         "organization"   The organization.
 *         "product"        The product.
 *         "component"      The component.
 *         "server"         The server.
 *         "client"         The client.
 *         "messageMask"    The mask which selects the message types to
 *                          be processed.
 *         "messageFile"    A message file name, used to translate message
 *                          keys.
 *         "suppressedKeys" A blank-delimited set of message keys which
 *                          are not to be processed.
 *         </pre>
 *         All values are <code>Strings</code>.
 *         The parent and extensions of this object may add additional keys.
 **/

public Hashtable getConfig();


/*----------------------------------------------------------------------
 * Name:  setConfig
 *--------------------------------------------------------------------*/
/**
 * Sets the configuration of this object.  This method is used by a 
 * <code>RASManager</code> to initialize a RAS object.  It should not 
 * be necessary for an application to use this method.
 *
 * @param ht  A <code>Hashtable</code> containing the configuration.
 *            This object searches for the following keys:
 *            <pre>
 *            "messageMask"    The mask which selects the message types to
 *                             be processed.
 *            "organization"   The organization.
 *            "product"        The product.
 *            "component"      The component.
 *            "server"         The server.
 *            "client"         The client.
 *            "messageMask"    The mask which selects the message types to
 *                             be processed.
 *            "messageFile"    A message file name, used to translate message
 *                             keys.
 *            "suppressedKeys" A blank-delimited set of message keys which
 *                             are not to be processed.
 *            </pre>
 *            All values are <code>Strings</code>.
 *            If a key is not found, that configuration element is not
 *            updated.
 *            The parent and extensions of this object may use additional keys.
 **/

public void setConfig(Hashtable ht);


/*----------------------------------------------------------------------
 * Name:  getMessageMask
 *--------------------------------------------------------------------*/
/**
 * Gets the mask which defines the set of message types that will be 
 * processed.  Possible values are defined by the logical OR of the  
 * <code>RASIMessageEvent.TYPE_XXXX</code> constants.
 *
 * @return The message mask.
 */

public long getMessageMask();


/*----------------------------------------------------------------------
 * Name:  setMessageMask
 *--------------------------------------------------------------------*/
/**
 * Sets the mask which defines the set of message types that will be 
 * processed.  Possible values are defined by the logical OR of the  
 * <code>RASIMessageEvent.TYPE_XXXX</code> constants.
 * The mask value is not validated against these types.
 *
 * @param mask The message mask.
 */

public void setMessageMask(long mask);


/*----------------------------------------------------------------------
 * Name:  getOrganization
 *--------------------------------------------------------------------*/
/**
 * Gets the name of the organization which wrote the application that
 * is using this logger.
 * 
 * @return The organization name, or an empty string ("") if the
 *         organization has not been set.
 **/

public String getOrganization();


/*----------------------------------------------------------------------
 * Name:  setOrganization
 *--------------------------------------------------------------------*/
/**
 * Sets the name of the organization which wrote the application that
 * is using this logger.  If the name is <code>null</code>, the current
 * name is not changed.
 * 
 * @param name The organization name.
 **/

public void setOrganization(String name);


/*----------------------------------------------------------------------
 * Name:  getProduct
 *--------------------------------------------------------------------*/
/**
 * Gets the name of the product that is using this logger.
 * 
 * @return The product name, or an empty string ("") if the
 *         product has not been set.
 **/

public String getProduct();


/*----------------------------------------------------------------------
 * Name:  setProduct
 *--------------------------------------------------------------------*/
/**
 * Sets the name of the product that is using this logger.  If the name
 * is <code>null</code>, the current name is not changed.
 * 
 * @param name The product name.
 **/

public void setProduct(String name);


/*----------------------------------------------------------------------
 * Name:  getComponent
 *--------------------------------------------------------------------*/
/**
 * Gets the name of the component that is using this logger.
 * 
 * @return The component name, or an empty string ("") if the
 *         component has not been set.
 **/

public String getComponent();


/*----------------------------------------------------------------------
 * Name:  setComponent
 *--------------------------------------------------------------------*/
/**
 * Sets the name of the component that is using this logger.  If the name
 * is <code>null</code>, the current name is not changed.
 * 
 * @param name The component name.
 **/

public void setComponent(String name);


/*----------------------------------------------------------------------
 * Name:  getServer
 *--------------------------------------------------------------------*/
/**
 * Gets the name of the server which is associated with this logger.
 * 
 * @return The server name, or an empty string ("") if the server has
 *         not been set.
 **/

public String getServer();


/*----------------------------------------------------------------------
 * Name:  setServer
 *--------------------------------------------------------------------*/
/**
 * Sets the name of the server which is associated with this logger.
 * If the name is <code>null</code>, the current name is not changed.
 * 
 * @param name  The server name.
 **/

public void setServer(String name);


/*----------------------------------------------------------------------
 * Name:  getClient
 *--------------------------------------------------------------------*/
/**
 * Gets the name of the client which is associated with this logger.
 * 
 * @return The client name, or an empty string ("") if the client has
 *         not been set.
 **/

public String getClient();


/*----------------------------------------------------------------------
 * Name:  setClient
 *--------------------------------------------------------------------*/
/**
 * Sets the name of the client which is associated with this logger.
 * If the name is <code>null</code>, the current name is not changed.
 * 
 * @param name The client name.
 **/

public void setClient(String name);


/*----------------------------------------------------------------------
 * Name:  getMessageFile
 *--------------------------------------------------------------------*/
/**
 * Gets the message file associated with this logger.
 *
 * @return The message file name, or <code>null</code> if a message file
 *         has not been added to the logger. 
 **/

public String getMessageFile();


/*----------------------------------------------------------------------
 * Name:  setMessageFile
 *--------------------------------------------------------------------*/
/**
 * Sets the message file associated with this logger.  If the file
 * is <code>null</code>, the current message file is not changed.
 * If the message file does not exist, a message indicating this will
 * be displayed in place of the formatted message.
 *
 * @param file The message file name.
 **/

public void setMessageFile(String file);


/*----------------------------------------------------------------------
 * Name:  addSuppressedKey
 *--------------------------------------------------------------------*/
/**
 * Adds a message key to a set of keys which should not be logged.
 * More than one message key may be in this set.  If the key is 
 * <code>null</code> or is already registered, this method does nothing.
 *
 * @param key The message key which is not to be logged.
 **/

public void addSuppressedKey(String key);


/*----------------------------------------------------------------------
 * Name:  removeSuppressedKey
 *--------------------------------------------------------------------*/
/**
 * Removes a message key from the set of keys which should not be logged.
 * If the key is <code>null</code> or is not registered, this method
 * does nothing.
 *
 * @param key The message key to be removed.
 **/

public void removeSuppressedKey(String key);


/*----------------------------------------------------------------------
 * Name:  getSuppressedKeys
 *--------------------------------------------------------------------*/
/**
 * Gets all of the suppressed message keys associated with this logger.
 *
 * @return A <code>Vector</code> of message keys.  If no suppressed keys
 *         are registered, the <code>Vector</code> is empty.
 **/

public Vector getSuppressedKeys();


/*----------------------------------------------------------------------
 * Name:  message
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key, with no parameters.
 * This call can be used in a non-static method and assumes that at
 * least one message file is registered with the logger.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param key        The message key.
 */

public void message(long type, Object obj, String methodName, String key);


/*----------------------------------------------------------------------
 * Name:  message
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key, with one parameter.
 * This call can be used in a non-static method and assumes that at
 * least one message file is registered with the logger.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param parm1      An element to be inserted into the message.
 */

public void message(long type, Object obj, String methodName, String key,
                    Object parm1);


/*----------------------------------------------------------------------
 * Name:  message
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key, with two parameters.
 * This call can be used in a non-static method and assumes that at
 * least one message file is registered with the logger.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param parm1      An element to be inserted into the message.
 * @param parm2      An element to be inserted into the message.
 */

public void message(long type, Object obj, String methodName, String key,
                    Object parm1,
                    Object parm2);


/*----------------------------------------------------------------------
 * Name:  message
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key, with an array of parameters.
 * This call can be used in a non-static method and assumes that at
 * least one message file is registered with the logger.
 *
 * @param type       The type of the message.                   
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param parms      An array of elements to be inserted into the message.
 */

public void message(long type, Object obj, String methodName, String key,
                    Object[] parms);


/*----------------------------------------------------------------------
 * Name:  message
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key, with no parameters.
 * This call can be used in any method and assumes that at
 * least one message file is registered with the logger.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class.
 * @param methodName The name of the logging method.
 * @param key        The message key.
 */

public void message(long type, String className, String methodName, String key);


/*----------------------------------------------------------------------
 * Name:  message
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key, with one parameter.
 * This call can be used in any method and assumes that at
 * least one message file is registered with the logger.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class. 
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param parm1      An element to be inserted into the message.
 */

public void message(long type, String className, String methodName, String key,
                    Object parm1);


/*----------------------------------------------------------------------
 * Name:  message
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key, with two parameters.
 * This call can be used in any method and assumes that at
 * least one message file is registered with the logger.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class. 
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param parm1      An element to be inserted into the message.
 * @param parm2      An element to be inserted into the message.
 */

public void message(long type, String className, String methodName, String key,
                    Object parm1, 
                    Object parm2);


/*----------------------------------------------------------------------
 * Name:  message
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key, with an array of parameters.
 * This call can be used in any method and assumes that at
 * least one message file is registered with the logger.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class. 
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param parms      An array of elements to be inserted into the message.
 */                

public void message(long type, String className, String methodName, String key,
                    Object[] parms);


/*----------------------------------------------------------------------
 * Name:  msg
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key and file, with no parameters.
 * This call can be used in a non-static method.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param file       The name of the message file to use.
 */

public void msg(long type, Object obj, String methodName, String key, String file);


/*----------------------------------------------------------------------
 * Name:  msg
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key and file with one parameter.
 * This call can be used in a non-static method.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param file       The name of the message file to use.
 * @param parm1      An element to be inserted into the message.
 */

public void msg(long type, Object obj, String methodName, String key, String file,
                Object parm1);


/*----------------------------------------------------------------------
 * Name:  msg
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key and file, with two parameters.
 * This call can be used in a non-static method.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param file       The name of the message file to use.
 * @param parm1      An element to be inserted into the message.
 * @param parm2      An element to be inserted into the message.
 */

public void msg(long type, Object obj, String methodName, String key, String file,
                Object parm1, 
                Object parm2);


/*----------------------------------------------------------------------
 * Name:  msg
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key and file, with an array of parameters.
 * This call can be used in a non-static method.
 *
 * @param type       The type of the message.                   
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param file       The name of the message file to use.
 * @param parms      An array of elements to be inserted into the message.
 */

public void msg(long type, Object obj, String methodName, String key, String file,
                Object[] parms);


/*----------------------------------------------------------------------
 * Name:  msg
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key and file, with no parameters.
 * This call can be used in any method.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class.
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param file       The name of the message file to use.
 */

public void msg(long type, String className, String methodName, String key, String file);


/*----------------------------------------------------------------------
 * Name:  msg
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key and file, with one parameter.
 * This call can be used in any method.
 *
 * @param type        The type of the message.
 * @param className   The name of the logging class. 
 * @param methodName  The name of the logging method.
 * @param key         The message key.
 * @param file        The name of the message file to use.
 * @param parm1       An element to be inserted into the message.
 */

public void msg(long type, String className, String methodName, String key, String file,
                Object parm1);


/*----------------------------------------------------------------------
 * Name:  msg
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key and file, with two parameters.
 * This call can be used in any method.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class. 
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param file       The name of the message file to use.
 * @param parm1      An element to be inserted into the message.
 * @param parm2      An element to be inserted into the message.
 */

public void msg(long type, String className, String methodName, String key, String file,
                Object parm1, 
                Object parm2);


/*----------------------------------------------------------------------
 * Name:  msg
 *--------------------------------------------------------------------*/
/**
 * Logs a message, by key and file, with an array of parameters.
 * This call can be used in any method.
 *
 * @param type       The type of the message.                   
 * @param className  The name of the logging class.
 * @param methodName The name of the logging method.
 * @param key        The message key.
 * @param file       The name of the message file to use.
 * @param parms      An array of elements to be inserted into the message.
 */

public void msg(long type, String className, String methodName, String key, String file,
                Object[] parms);


/*----------------------------------------------------------------------
 * Name:  textMessage
 *--------------------------------------------------------------------*/
/**
 * Logs a text message (no key) with no parameters.
 * This call can be used in a non-static method.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param text       The message text.
 */

public void textMessage(long type, Object obj, String methodName, String text);


/*----------------------------------------------------------------------
 * Name:  textMessage
 *--------------------------------------------------------------------*/
/**
 * Logs a text message (no key) with one parameter.
 * This call can be used in a non-static method.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param text       The message text.
 * @param parm1      An element to be displayed with the message.
 */

public void textMessage(long type, Object obj, String methodName, String text,
                        Object parm1);


/*----------------------------------------------------------------------
 * Name:  textMessage
 *--------------------------------------------------------------------*/
/**
 * Logs a text message (no key) with two parameters.
 * This call can be used in a non-static method.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param text       The message text.
 * @param parm1      An element to be displayed with the message.
 * @param parm2      An element to be displayed with the message.
 */

public void textMessage(long type, Object obj, String methodName, String text,
                        Object parm1, 
                        Object parm2);


/*----------------------------------------------------------------------
 * Name:  textMessage
 *--------------------------------------------------------------------*/
/**
 * Logs a text message (no key) with an array of parameters.
 * This call can be used in a non-static method.
 *
 * @param type       The type of the message.
 * @param obj        The logging object ("this").
 * @param methodName The name of the logging method.
 * @param text       The message text.
 * @param parms      An array of elements to be displayed with the message.
 */

public void textMessage(long type, Object obj, String methodName, String text,
                        Object[] parms);


/*----------------------------------------------------------------------
 * Name:  textMessage
 *--------------------------------------------------------------------*/
/**
 * Logs a text message (no key) with no parameters.
 * This call can be used in any method.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class. 
 * @param methodName The name of the logging method.
 * @param text       The message text.
 */                

public void textMessage(long type, String className, String methodName, String text);


/*----------------------------------------------------------------------
 * Name:  textMessage
 *--------------------------------------------------------------------*/
/**
 * Logs a text message (no key) with one parameter.
 * This call can be used in any method.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class. 
 * @param methodName The name of the logging method.
 * @param text       The message text.
 * @param parm1      An element to be displayed with the message.
 */                

public void textMessage(long type, String className, String methodName, String text,
                        Object parm1);


/*----------------------------------------------------------------------
 * Name:  textMessage
 *--------------------------------------------------------------------*/
/**
 * Logs a text message (no key) with two parameters.
 * This call can be used in any method.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class. 
 * @param methodName The name of the logging method.
 * @param text       The message text.
 * @param parm1      An element to be displayed with the message.
 * @param parm2      An element to be displayed with the message.
 */                

public void textMessage(long type, String className, String methodName, String text,
                        Object parm1, 
                        Object parm2);


/*----------------------------------------------------------------------
 * Name:  textMessage
 *--------------------------------------------------------------------*/
/**
 * Logs a text message (no key) with an array of parameters.
 * This call can be used in any method.
 *
 * @param type       The type of the message.
 * @param className  The name of the logging class.
 * @param methodName The name of the logging method.
 * @param text       The message text.
 * @param parms      An array of elements to be displayed with the message.
 */

public void textMessage(long type, String className, String methodName, String text,
                        Object[] parms);
}
