/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.util.*;

/**
 * <code>RASIObject/code> defines the methods which are common to 
 * the <code>RASILogger, RASIHandler</code> and <code>RASIFormatter</code>
 * interfaces.  This interface is intended to be extended by these  
 * other interface and should not be implemented directly.
 *
 * @see RASILogger
 * @see RASIHandler
 * @see RASIFormatter
 */

public interface RASIObject
{

/*----------------------------------------------------------------------
 * Name:  getConfig
 *--------------------------------------------------------------------*/
/**
 * Gets the configuration of this object.
 *
 * @return A <code>Hashtable</code> containing the configuration.
 *         This object inserts the following key/value pairs into the
 *         configuration:
 *         <pre>
 *         "name"        The name of the object.
 *         "description" The description of the object.
 *         </pre>
 *         All values are <code>Strings</code>.
 *         Extensions to this object may add additional keys.
 **/

public Hashtable getConfig();


/*----------------------------------------------------------------------
 * Name:  setConfig
 *--------------------------------------------------------------------*/
/**
 * Sets the configuration of this object.  This method is used by a 
 * <code>RASManager</code> to initialize a RAS object.  It should not 
 * be necessary for an application to use this method.
 *
 * @param ht  A <code>Hashtable</code> containing the configuration.
 *            This object searches for the following keys:
 *            <pre>
 *            "name"        The name of the object.
 *            "description" The description of the object.
 *            </pre>
 *            All values are <code>Strings</code>.
 *            If a key is not found, that configuration element is not
 *            updated.
 *            Extensions to this object may use additional keys.
 **/

public void setConfig(Hashtable ht);


/*----------------------------------------------------------------------
 * Name:  getName
 *--------------------------------------------------------------------*/
/**
 * Gets the name by which this object is known.
 *
 * @return The name of this object, or an empty string ("") if the name 
 *         has not been set.
 */

public String getName();


/*----------------------------------------------------------------------
 * Name:  setName
 *--------------------------------------------------------------------*/
/**
 * Sets the name by which this object is known.  If the name is 
 * <code>null</code>, the current name is not changed.
 *
 * @param name The name of this object.
 */

public void setName(String name);


/*----------------------------------------------------------------------
 * Name:  getDescription
 *--------------------------------------------------------------------*/
/**
 * Gets the description of this object.
 *
 * @return The description of this object, or an empty string ("") if 
 *         the description has not been set.
 **/

public String getDescription();


/*----------------------------------------------------------------------
 * Name:  setDescription
 *--------------------------------------------------------------------*/
/**
 * Sets the description of this object.  If the description is 
 * <code>null</code>, the current description is not changed.
 *
 * @param desc The description of this object.
 **/

public void setDescription(String desc);
}
