/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

/**
 * <code>RASITraceEvent</code> defines a set of constants related to
 * <code>RASTraceEvents</code>.
 */

public interface RASITraceEvent
{

/**
 * Defines an Application Programming Interface (API) 
 * trace point.
 */

public static final long TYPE_API = 0x0001;

/**
 * Defines a callback method trace point.
 */

public static final long TYPE_CALLBACK = 0x0002;

/**
 * Defines method entry and exit trace points.
 */

public static final long TYPE_ENTRY_EXIT = 0x0004;

/**
 * Defines an error or exception condition trace point.
 */

public static final long TYPE_ERROR_EXC = 0x0008;

/**
 * Defines a miscellaneous data trace point.
 */

public static final long TYPE_MISC_DATA = 0x0010;

/**
 * Defines an object creation (constructor) trace point.
 */

public static final long TYPE_OBJ_CREATE = 0x0020;

/**
 * Defines an object deletion (destructor) trace point.
 */

public static final long TYPE_OBJ_DELETE = 0x0040;

/**
 * Defines a <code>private</code> method trace point.
 */

public static final long TYPE_PRIVATE = 0x0080;

/**
 * Defines a public method trace point.  (This typically
 * includes <code>package</code> and <code>protected</code>
 * scope, as all of these methods may be used by other 
 * classes.)
 */

public static final long TYPE_PUBLIC = 0x0100;

/**
 * Defines a static method trace point.
 */

public static final long TYPE_STATIC = 0x0200;

/**
 * Defines a service code trace point.  Service code is
 * generally "low-level" code which provides commonly used services
 * to other classes.
 */

public static final long TYPE_SVC = 0x0400;

/**
 * Defines a "low-detail" trace point.  Some trace implementations 
 * prefer the notion of a "trace level," in which level 1 implies
 * minimal detail, level 2 implies more detail and level 3 implies
 * the most detail.  In such a system, these three types would be
 * used exclusively.
 */

public static final long TYPE_LEVEL1 = 0x0800;

/**
 * Defines a "medium-detail" trace point.  Some trace implementations 
 * prefer the notion of a "trace level," in which level 1 implies
 * minimal detail, level 2 implies more detail and level 3 implies
 * the most detail.  In such a system, these three types would be
 * used exclusively.
 */

public static final long TYPE_LEVEL2 = 0x1000;

/**
 * Defines a "high-detail" trace point.  Some trace implementations 
 * prefer the notion of a "trace level," in which level 1 implies
 * minimal detail, level 2 implies more detail and level 3 implies
 * the most detail.  In such a system, these three types would be
 * used exclusively.
 */

public static final long TYPE_LEVEL3 = 0x2000;

/**
 * Defines the default mask, which includes the trace types to be
 * processed.  This value is used by the loggers and the handlers.
 */

public static final long DEFAULT_TRACE_MASK = 
  TYPE_API |
  TYPE_CALLBACK |
  TYPE_ENTRY_EXIT |
  TYPE_ERROR_EXC |
  TYPE_MISC_DATA |
  TYPE_OBJ_CREATE |
  TYPE_OBJ_DELETE |
  TYPE_PRIVATE |
  TYPE_PUBLIC |
  TYPE_STATIC |
  TYPE_SVC;
}
