/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.util.*;

/**
 * <code>RASITraceLogger</code> defines a set of methods that must be 
 * implemented to create RAS trace data.
 *
 * @see RASILogger
 * @see RASTraceLogger
 */

public interface RASITraceLogger extends RASILogger
{

/*----------------------------------------------------------------------
 * Name:  getConfig
 *--------------------------------------------------------------------*/
/**
 * Gets the configuration of this object.
 *
 * @return A <code>Hashtable</code> containing the configuration.
 *         This object inserts the following key/value pairs into the
 *         configuration:
 *         <pre>
 *         "traceMask" The mask which selects the trace types to be
 *                     processed.
 *         </pre>
 *         All values are <code>Strings</code>.
 *         The parent and extensions of this object may add additional keys.
 **/

public Hashtable getConfig();


/*----------------------------------------------------------------------
 * Name:  setConfig
 *--------------------------------------------------------------------*/
/**
 * Sets the configuration of this object.  This method is used by a 
 * <code>RASManager</code> to initialize a RAS object.  It should not 
 * be necessary for an application to use this method.
 *
 * @param ht  A <code>Hashtable</code> containing the configuration.
 *            This object searches for the following keys:
 *            <pre>
 *            "traceMask" The mask which selects the trace types to be
 *                        processed.
 *            </pre>
 *            All values are <code>Strings</code>.
 *            If a key is not found, that configuration element is not
 *            updated.
 *            The parent and extensions of this object may use additional keys.
 **/

public void setConfig(Hashtable ht);


/*----------------------------------------------------------------------
 * Name:  getTraceMask
 *--------------------------------------------------------------------*/
/**
 * Gets the mask which defines the set of trace types that will be 
 * processed.  Possible values are defined by the logical OR of the
 * <code>RASITraceEvent.TYPE_XXXX</code> constants.
 *
 * @return The trace mask.
 */

public long getTraceMask();


/*----------------------------------------------------------------------
 * Name:  setTraceMask
 *--------------------------------------------------------------------*/
/**
 * Sets the mask which defines the set of trace types that will be 
 * processed.  Possible values are defined by the
 * <code>RASITraceEvent.TYPE_XXXX</code> constants.
 * The mask value is not validated against these types.
 *
 * @param mask The trace mask.
 */

public void setTraceMask(long mask);


/*----------------------------------------------------------------------
 * Name:  entry
 *--------------------------------------------------------------------*/
/**
 * Traces entry into a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 */

public void entry(long type, Object obj, String methodName);


/*----------------------------------------------------------------------
 * Name:  entry
 *--------------------------------------------------------------------*/
/**
 * Traces entry into a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param parm1      An element to be displayed as trace data.
 */

public void entry(long type, Object obj, String methodName, 
                  Object parm1);


/*----------------------------------------------------------------------
 * Name:  entry
 *--------------------------------------------------------------------*/
/**
 * Traces entry into a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param parm1      An element to be displayed as trace data.
 * @param parm2      An element to be displayed as trace data.
 */

public void entry(long type, Object obj, String methodName, 
                  Object parm1, 
                  Object parm2);


/*----------------------------------------------------------------------
 * Name:  entry
 *--------------------------------------------------------------------*/
/**
 * Traces entry into a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param parms      An array of parameters passed to the method.
 */

public void entry(long type, Object obj, String methodName, 
                  Object[] parms);


/*----------------------------------------------------------------------
 * Name:  entry
 *--------------------------------------------------------------------*/
/**
 * Traces entry into a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.
 * @param methodName The name of the traced method.
 */

public void entry(long type, String className, String methodName);


/*----------------------------------------------------------------------
 * Name:  entry
 *--------------------------------------------------------------------*/
/**
 * Traces entry into a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.             
 * @param methodName The name of the traced method.
 * @param parm1      An element to be displayed as trace data.
 */

public void entry(long type, String className, String methodName, 
                  Object parm1);


/*----------------------------------------------------------------------
 * Name:  entry
 *--------------------------------------------------------------------*/
/**
 * Traces entry into a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.             
 * @param methodName The name of the traced method.
 * @param parm1      An element to be displayed as trace data.
 * @param parm2      An element to be displayed as trace data.
 */

public void entry(long type, String className, String methodName, 
                  Object parm1, 
                  Object parm2);


/*----------------------------------------------------------------------
 * Name:  entry
 *--------------------------------------------------------------------*/
/**
 * Traces entry into a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.             
 * @param methodName The name of the traced method.
 * @param parms      An array of parameters passed to the method.
 */

public void entry(long type, String className, String methodName, 
                  Object[] parms);


/*----------------------------------------------------------------------
 * Name:  exit
 *--------------------------------------------------------------------*/
/**
 * Traces exit from a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 */

public void exit(long type, Object obj, String methodName);


/*----------------------------------------------------------------------
 * Name:  exit
 *--------------------------------------------------------------------*/
/**
 * Traces exit from a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param retValue   The returned value.
 */

public void exit(long type, Object obj, String methodName,
                 Object retValue);


/*----------------------------------------------------------------------
 * Name:  exit
 *--------------------------------------------------------------------*/
/**
 * Traces exit from a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.             
 * @param methodName The name of the traced method.
 */

public void exit(long type, String className, String methodName);


/*----------------------------------------------------------------------
 * Name:  exit
 *--------------------------------------------------------------------*/
/**
 * Traces exit from a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.             
 * @param methodName The name of the traced method.
 * @param retValue   The returned value.
 */

public void exit(long type, String className, String methodName, 
                 Object retValue);


/*----------------------------------------------------------------------
 * Name:  trace
 *--------------------------------------------------------------------*/
/**
 * Traces data in a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param text       The trace text.
 */

public void trace(long type, Object obj, String methodName, String text);


/*----------------------------------------------------------------------
 * Name:  trace
 *--------------------------------------------------------------------*/
/**
 * Traces data in a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param text       The trace text.
 * @param parm1      An element to be displayed as trace data.
 */

public void trace(long type, Object obj, String methodName, String text,
                  Object parm1);


/*----------------------------------------------------------------------
 * Name:  trace
 *--------------------------------------------------------------------*/
/**
 * Traces data in a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param text       The trace text.
 * @param parm1      An element to be displayed as trace data.
 * @param parm2      An element to be displayed as trace data.
 */

public void trace(long type, Object obj, String methodName, String text,
                  Object parm1, 
                  Object parm2);


/*----------------------------------------------------------------------
 * Name:  trace
 *--------------------------------------------------------------------*/
/**
 * Traces data in a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param text       The trace text.
 * @param parms      An array of elements to be displayed as trace data.
 */

public void trace(long type, Object obj, String methodName, String text,
                  Object[] parms);


/*----------------------------------------------------------------------
 * Name:  trace
 *--------------------------------------------------------------------*/
/**
 * Traces data in a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.
 * @param methodName The name of the traced method.
 * @param text       The trace text.
 */

public void trace(long type, String className, String methodName, String text);


/*----------------------------------------------------------------------
 * Name:  trace
 *--------------------------------------------------------------------*/
/**
 * Traces data in a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.
 * @param methodName The name of the traced method.
 * @param text       The trace text.
 * @param parm1      An element to be displayed as trace data.
 */

public void trace(long type, String className, String methodName, String text,
                  Object parm1);


/*----------------------------------------------------------------------
 * Name:  trace
 *--------------------------------------------------------------------*/
/**
 * Traces data in a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.
 * @param methodName The name of the traced method.
 * @param text       The trace text.
 * @param parm1      An element to be displayed as trace data.
 * @param parm2      An element to be displayed as trace data.
 */

public void trace(long type, String className, String methodName, String text,
                  Object parm1, 
                  Object parm2);


/*----------------------------------------------------------------------
 * Name:  trace
 *--------------------------------------------------------------------*/
/**
 * Traces data in a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.
 * @param methodName The name of the traced method.
 * @param text       The trace text.
 * @param parms      An array of elements to be displayed as trace data.
 */

public void trace(long type, String className, String methodName, String text,
                  Object[] parms);


/*----------------------------------------------------------------------
 * Name:  exception
 *--------------------------------------------------------------------*/
/**
 * Traces an <code>Exception</code> in a non-static method.
 *
 * @param type       The type of the trace point.
 * @param obj        The traced object ("this").
 * @param methodName The name of the traced method.
 * @param exc        An exception.
 */

public void exception(long type, Object obj, String methodName,
                      Exception exc);


/*----------------------------------------------------------------------
 * Name:  exception
 *--------------------------------------------------------------------*/
/**
 * Traces an <code>Exception</code> in a static method.
 *
 * @param type       The type of the trace point.
 * @param className  The name of the traced class.
 * @param methodName The name of the traced method.
 * @param exc        An exception.
 */

public void exception(long type, String className, String methodName,
                      Exception exc);
}
