/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.util.*;

/**
 * <code>RASObject</code> defines the methods which are common to the 
 * <code>RASLogger, RASHandler</code> and <code>RASFormatter</code> classes.
 * It should not be necessary to create an instance of this class directly.
 * <p>
 * The elements common to loggers and handlers include:
 * <ul>
 * <li>The name of the object.
 * <li>A description of the object.
 * </ul>
 *
 * @see RASLogger
 * @see RASHandler
 * @see RASFormatter
 */

public class RASObject
{
private static final String S = RASCopyright.COPYRIGHT_98;

/**
 * The description of this <code>RASObject</code>.
 */

private String desc = "";

/**
 * The name of this <code>RASObject</code>.
 */

private String name = "";


/*----------------------------------------------------------------------
 * Name:  RASObject
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASObject</code>.  The name and description of this
 * object are empty strings.
 */

public RASObject() 
{
this("", "");
}


/*----------------------------------------------------------------------
 * Name:  RASObject
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASObject</code>.  The description of this object is
 * an empty string.
 *
 * @param name The name of this object.
 */

public RASObject(String name) 
{
this(name, "");
}


/*----------------------------------------------------------------------
 * Name:  RASObject
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASObject</code>.
 *
 * @param name The name of this object.
 * @param desc The description of this object.
 */

public RASObject(String name, String desc) 
{
setName(name);
setDescription(desc);
}


/*----------------------------------------------------------------------
 * Name:  getConfig
 *--------------------------------------------------------------------*/
/**
 * Gets the configuration of this object.
 *
 * @return A <code>Hashtable</code> containing the configuration.
 *         This object inserts the following key/value pairs into the
 *         configuration:
 *         <pre>
 *         "name"        The name of the object.
 *         "description" The description of the object.
 *         </pre>
 *         All values are <code>Strings</code>.
 *         Extensions to this object may add additional keys.
 **/

public Hashtable getConfig()
{
Hashtable ht = new Hashtable();

ht.put("name", getName());
ht.put("description", getDescription());

return ht;
}


/*----------------------------------------------------------------------
 * Name:  setConfig
 *--------------------------------------------------------------------*/
/**
 * Sets the configuration of this object.  This method is used by a 
 * <code>RASManager</code> to initialize a RAS object.  It should not 
 * be necessary for an application to use this method.
 *
 * @param ht  A <code>Hashtable</code> containing the configuration.
 *            This object searches for the following keys:
 *            <pre>
 *            "name"        The name of the object.
 *            "description" The description of the object.
 *            </pre>
 *            All values are <code>Strings</code>.
 *            If a key is not found, that configuration element is not
 *            updated.
 *            Extensions to this object may use additional keys.
 **/

public void setConfig(Hashtable ht)
{
if (ht.containsKey("name"))
  setName((String) ht.get("name"));
if (ht.containsKey("description"))
   setDescription((String) ht.get("description"));
}


/*----------------------------------------------------------------------
 * Name:  getName
 *--------------------------------------------------------------------*/
/**
 * Gets the name by which this object is known.
 *
 * @return The name of this object, or an empty string ("") if the name 
 *         has not been set.
 */

public String getName() 
{
return name;
}


/*----------------------------------------------------------------------
 * Name:  setName
 *--------------------------------------------------------------------*/
/**
 * Sets the name by which this object is known.  If the name is 
 * <code>null</code>, the current name is not changed.
 *
 * @param name The name of this object.
 */

public void setName(String name) 
{
if (name != null)
  this.name = name;
}             


/*----------------------------------------------------------------------
 * Name:  getDescription
 *--------------------------------------------------------------------*/
/**
 * Gets the description of this object.
 *
 * @return The description of this object, or an empty string ("") if 
 *         the description has not been set.
 **/

public String getDescription()
{
return desc;
}


/*----------------------------------------------------------------------
 * Name:  setDescription
 *--------------------------------------------------------------------*/
/**
 * Sets the description of this object.  If the description is 
 * <code>null</code>, the current description is not changed.
 *
 * @param desc The description of this object.
 **/

public void setDescription(String desc)
{
if (desc != null)
  this.desc = desc;
}

}
