/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras;

import java.util.*;

/**
 * This class contains constants and utility methods used by this 
 * package.
 */

public class RASUtil
{
private static final String S = RASCopyright.COPYRIGHT_98;

/**
 * The current version of the RAS Toolkit.
 */

public static final String RAS_VERSION = "Version 1.0";

/**
 * The catalog containing RAS messages and strings to be displayed.
 */

protected static RASMessageCatalog rasMsgs = 
  new RASMessageCatalog("com.ibm.ras.RASMsgs");


/*----------------------------------------------------------------------
 * Name:  createObject
 *--------------------------------------------------------------------*/
/**
 * Creates an <code>Object</code> from its class name.
 *
 * @param name The fully-qualified name of the object.
 *
 * @return The object, or <code>null</code> if the requested 
 *         object could not be created.
 */

public static Object createObject(String name)
{
Class objClass = null;
Object object = null;

try 
  {
  objClass = Class.forName(name);
  try 
    {
    object = (Object) objClass.newInstance();
    } 
  catch (InstantiationException iE) 
    {
    System.err.println(RASUtil.rasMsgs.getMessage("ERR_OBJ_CREATE", name));
    System.err.println(iE.getMessage());
    }
  catch (IllegalAccessException iaE) 
    {
    System.err.println(RASUtil.rasMsgs.getMessage("ERR_OBJ_CREATE", name));
    System.err.println(iaE.getMessage());
    }
  } 
catch (ClassNotFoundException cnfE) 
  {
  }

return object;
}


/**
 * Convert a <code>String</code> of blank-delimited strings to a
 * <code>Vector</code> of <code>Strings</code>.
 *
 * @param source The source <code>String</code> to convert.
 *
 * @return The <code>Vector</code> equivalent.
 */

public static Vector stringToVector(String source)
{
Vector result = new Vector();

StringTokenizer st = new StringTokenizer(source);
while (st.hasMoreTokens())
  result.addElement(st.nextToken().trim());

return result;
}


/**
 * Converts a <code>Vector</code> of <code>Strings</code> to a single line 
 * with elements separated by a single blank.
 *
 * @param source The source <code>Vector</code> of <code>Strings</code> to 
 *               convert.
 *
 * @return The <code>String</code> equivalent.
 */

public static String vectorToString(Vector source)
{
Enumeration e = source.elements();
String sep = "";
StringBuffer bfr = new StringBuffer();

while (e.hasMoreElements())
  {
  bfr.append(sep + e.nextElement());
  sep = " ";
  }

return bfr.toString();
}

}
