/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras.mgr;

import java.util.*;
import com.ibm.ras.*;

/**
 * <code>RASBaseGroup</code> is an extension of <code>RASGroup</code>.
 * It includes additional <code>RASGroups</code> as well as a set of
 * default handlers (which can be attached to a logger if the logger's
 * configuration does not include a handler).
 *
 * @see RASGroup
 * @see RASManager
 */

public class RASBaseGroup extends RASGroup
{
private static final String S = RASCopyright.COPYRIGHT_98;
	
/**
 * The <code>RASGroup</code> objects in this group.
 */

private Hashtable groups = new Hashtable();
	
/**
 * The default handlers.  A blank-delimited list of handler names to be
 * used if a RAS configuration does not include any handlers.
 */

private String defaultHandlers = null;
	

/*----------------------------------------------------------------------
 * Name:  RASBaseGroup
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASBaseGroup</code>.
 */

public RASBaseGroup() 
{
super("", "");
}


/*----------------------------------------------------------------------
 * Name:  addGroup
 *--------------------------------------------------------------------*/
/**
 * Adds a RAS group to this group.  If a RAS group with the same name is 
 * already a member of this base group, it is replaced.
 *
 * @param grp The RAS group to be added.
 **/

public void addGroup(RASGroup grp)
{
if (grp != null)
  groups.put(grp.getName(), grp);
}


/*----------------------------------------------------------------------
 * Name:  removeGroup
 *--------------------------------------------------------------------*/
/**
 * Removes a RAS group from this group.  If the named group does not 
 * exist, this method does nothing.
 *
 * @param grp The RAS group to be removed.
 **/

public void removeGroup(RASGroup grp)
{
if (grp != null)
  groups.remove(grp.getName());
}


/*----------------------------------------------------------------------
 * Name:  getGroup
 *--------------------------------------------------------------------*/
/**
 * Gets a RAS group from this group.
 *
 * @param name The name of the RAS group.
 *
 * @return The RAS group, or <code>null</code> if the named group does 
 *         not exist.
 **/

public RASGroup getGroup(String name)
{
RASGroup grp = null;
if (name != null)
  grp = (RASGroup) groups.get(name);
return grp;
}


/*----------------------------------------------------------------------
 * Name:  getGroups
 *--------------------------------------------------------------------*/
/**
 * Gets all of the RAS groups associated with this group.
 *
 * @return A <code>Hashtable</code> of RAS groups.
**/

public Hashtable getGroups()
{
return groups;
}


/*----------------------------------------------------------------------
 * Name:  getDefaultHandlers
 *--------------------------------------------------------------------*/
/**
 * Gets the default handlers, which will be associated with any
 * logger that does not have a "handlerNames" key in its configuration.
 *
 * @return A blank delimited <code>String</code> of handler names.
 **/

public String getDefaultHandlers()
{
return defaultHandlers;
}


/*----------------------------------------------------------------------
 * Name:  setDefaultHandlers
 *--------------------------------------------------------------------*/
/**
 * Sets the default handlers, which will be associated with any
 * logger that does not have a "handlerNames" key in its configuration.
 *
 * @param names A blank delimited <code>String</code> of handler names.
 **/

public void setDefaultHandlers(String names)
{
defaultHandlers = names;
}

}
