/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras.mgr;

import java.util.*;
import com.ibm.ras.*;
/**
 * <code>RASConfig</code> contains the configuration data for a RAS
 * object (a logger or handler).
 * <p>
 * A <code>RASConfig</code> contains the following items:
 * <ul>
 * <li>A<code>Hashtable</code> of configuration data for the object,
 * as described in the <code>getConfig</code> and <code>setConfig</code>
 * methods of the <code>RASObject</code> classes.  This data is passed
 * to the RAS object when it is created.
 * <li>An "in-use" count which tells how many applications are using the
 * RAS object.
 * <li>A reference to the <code>RASObject</code>, once the object has
 * been created.
 * </ul>
 *
 * @see RASManager
 * @see com.ibm.ras.RASILogger
 * @see com.ibm.ras.RASIHandler
 */

public class RASConfig
{
private static final String S = RASCopyright.COPYRIGHT_98;

/**
 * The configuration data for the <code>RASObject</code>.
 */

private Hashtable config = new Hashtable();

/**
 * The number of times this object has been requested.
 */

private int inUseCount = 0;

/**
 * A reference to the <code>RASObject</code> created from this configuration.
 */

private RASObject object = null;


/*----------------------------------------------------------------------
 * Name:  RASConfig
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASConfig</code>.
 *
 * @param config A <code>Hashtable</code> of configuration data for a
 *               <code>RASObject</code>.
 */

public RASConfig(Hashtable config)
{
setConfig(config);
}


/*----------------------------------------------------------------------
 * Name:  getConfig
 *--------------------------------------------------------------------*/
/**
 * Gets the configuration data held by this object.
 *
 * @return A <code>Hashtable</code> of configuration data for a
 *         <code>RASObject</code>.
 */

public Hashtable getConfig()
{
return config;
}


/*----------------------------------------------------------------------
 * Name:  setConfig
 *--------------------------------------------------------------------*/
/**
 * Sets the configuration data held by this object.  If a RAS object 
 * has been instantiated from this configuration, the new configuration
 * is also passed to the object.
 *
 * @param config A <code>Hashtable</code> of configuration data for a
 *               <code>RASObject</code>.
 */

public void setConfig(Hashtable config)
{
this.config = config;
RASObject object = getObject();
if (object != null)
  object.setConfig(config);
}


/*----------------------------------------------------------------------
 * Name:  getInUseCount
 *--------------------------------------------------------------------*/
/**
 * Gets the number of applications which are currently using this RAS
 * object.
 *
 * @return The in-use count.
 */

public int getInUseCount()
{
return inUseCount;
}


/*----------------------------------------------------------------------
 * Name:  setInUseCount
 *--------------------------------------------------------------------*/
/**
 * Sets the number of applications which are currently using this RAS
 * object.
 *
 * @param count The in-use count.
 */

public void setInUseCount(int count)
{
this.inUseCount = count;
}


/*----------------------------------------------------------------------
 * Name:  incrementInUseCount
 *--------------------------------------------------------------------*/
/**
 * Increments by one the number of applications which are currently using
 * this RAS object.
 *
 * @return The in-use count, after it has been incremented.
 */

public int incrementInUseCount()
{
inUseCount++;
return inUseCount;
}


/*----------------------------------------------------------------------
 * Name:  decrementInUseCount
 *--------------------------------------------------------------------*/
/**
 * Decrements by one the number of applications which are currently using
 * this RAS object.
 *
 * @return The in-use count, after it has been decremented.
 */

public int decrementInUseCount()
{
if (inUseCount > 0)
  inUseCount--;
return inUseCount;
}


/*----------------------------------------------------------------------
 * Name:  getObject
 *--------------------------------------------------------------------*/
/**
 * Gets a reference to the RAS object created from this configuration.
 *
 * @return The <code>RASObject</code>.
 */

public RASObject getObject()
{
return object;
}


/*----------------------------------------------------------------------
 * Name:  setObject
 *--------------------------------------------------------------------*/
/**
 * Sets a reference to the RAS object created from this configuration.
 *
 * @param object The <code>RASObject</code>.
 */

public void setObject(RASObject object)
{
this.object = object;
}

}
