/*----------------------------------------------------------------------
 * IBM Confidential
 * OCO Source Materials
 *
 * (C) Copyright IBM Corporation 1998.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 *--------------------------------------------------------------------*/

package com.ibm.ras.server;

import java.net.*;
import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Date;

import com.ibm.ras.*;

/**
 * <code>RASConnectionHandler</code> processes individual client connections.
 * This thread loops continuously, writing to the console and/or file
 * until the client socket disconnects.
 **/

public class RASConnectionHandler implements Runnable
{

/**
 * A flag set <code>true</code> if this handler will write to a file.
 **/

private boolean toFile = false;

/**
 * The <code>PrintWriter</code> that sends the data to its destination.
 */

private PrintWriter pWriter = null;

/**
 * The catalog containing the messages displayed by this class.
 */

private RASMessageCatalog cat = 
  new RASMessageCatalog("com.ibm.ras.server.RASLogServerMsgs");

/**
 * The <code>SimpleDateFormat</code> object used to format the 
 * time stamp.  The default format is "yyyy.MM.dd HH:mm:ss:SSS".
 */

private static SimpleDateFormat df = 
  new SimpleDateFormat("yyyy.MM.dd HH:mm:ss:SSS");

/**
 * The client TCP socket on which data is received.
 */

private Socket socket = null;


/*----------------------------------------------------------------------
 * Name:  RASConnectionHandler
 *--------------------------------------------------------------------*/
/**
 * Creates a <code>RASConnectionHandler</code>.
 *
 * @param socket  The socket on which to listen.
 * @param toFile  <code>true</code> to write the data to a file; 
 *                <code>false</code>, otherwise.
 * @param pWriter The <code>PrintWriter</code> to use.
 **/

public RASConnectionHandler(Socket socket, boolean toFile, PrintWriter pWriter)
{
this.socket = socket;
this.toFile = toFile;
this.pWriter = pWriter;

String dateString = df.format(new Date());
write(cat.getMessage("CONNECTION_OPENED", 
                     socket.getInetAddress().getHostName(), dateString));
}


/*----------------------------------------------------------------------
 * Name:  run
 *--------------------------------------------------------------------*/
/**
 * Starts the <code>RASConnectionHandler</code> on its own thread.
 **/

public void run()
{
// Get the input stream from the socket.

BufferedReader clientStream = null;
try
  {
  clientStream = new BufferedReader(new InputStreamReader(socket.getInputStream()));
  }
catch (Throwable e)
  {
  write(cat.getMessage("ERR_INPUT_STREAM"));
  write(e.getMessage());
  return;
  }

// Loop until the connection is destroyed.  This can be determined
// via readLine returning a null or by an exception (usually an
// IOException named recv.
//
// Simply take the line that is read from the socket and print it
// locally.

while (true)
  {
  try
    {
    String s = null;
    if ((s = clientStream.readLine()) == null)
      return;

    write(s);

    }
  catch (Throwable e)
    {
    String dateString = df.format(new Date());
    write(cat.getMessage("CONNECTION_CLOSED",
                         socket.getInetAddress().getHostName(), dateString));
    write(e.getMessage());
    return;
    }
  }
}


/*----------------------------------------------------------------------
 * Name:  write
 *--------------------------------------------------------------------*/
/**
  * Writes to the screen and, optionally, a file.
  *
  * @param msg The message to write.
  **/

private void write(String msg)
{
if (toFile)
  pWriter.println(msg);

System.out.println(msg);
}

}
